@@ -503,7 +503,8 @@ gboolean desktop_cmd_exec_connection_event (ConIcConnection *connection, ConIcCo
 	{
 		self->priv->isConnected = FALSE;
 	}
-	desktop_cmd_exec_update_content(self);
+	if(self->priv->updNeworkPolicy != NETWORK__UNRELATED)
+		desktop_cmd_exec_update_content(self);
 	return TRUE;
 }
 
@@ -958,14 +959,15 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 
 		
 		GtkWidget *updIntervalLabel = gtk_label_new ("");
-		gtk_label_set_markup (GTK_LABEL (updIntervalLabel), "<small>'0' disables periodic updating</small>");
+		gtk_label_set_markup (GTK_LABEL (updIntervalLabel), "<small>'0' disables periodic updating.</small>");
+		gtk_misc_set_alignment (GTK_MISC (updIntervalLabel), 0, 0);
 		gtk_container_add (GTK_CONTAINER (content_area), updIntervalLabel);
 
 
 		GtkWidget *networkPolicySel = hildon_touch_selector_new_text ();
-		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "Doesn't Matter");
-		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "Only when connected");
-		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "Only when disconnected");
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "Disabled (Doesn't Matter)");
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "When connected");
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "When disconnected");
 		hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (networkPolicySel), 0, self->priv->updNeworkPolicy);
 		
 		GtkWidget * networkPolBt = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
@@ -974,6 +976,12 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		hildon_button_set_alignment (HILDON_BUTTON (networkPolBt), 0, 0.5, 0, 0);
 		hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (networkPolBt), HILDON_TOUCH_SELECTOR (networkPolicySel));
 		gtk_container_add (GTK_CONTAINER (content_area), networkPolBt);
+
+		GtkWidget *networkPolBtHelp = gtk_label_new ("");
+		gtk_label_set_markup (GTK_LABEL (networkPolBtHelp), "<small>If enabled, the selected network event will trigger the command.</small>");
+		gtk_misc_set_alignment (GTK_MISC (networkPolBtHelp), 0, 0);
+		gtk_label_set_line_wrap (GTK_LABEL (networkPolBtHelp), TRUE);
+		gtk_container_add (GTK_CONTAINER (content_area), networkPolBtHelp);
 		
 		
 		//END
